==> api-builder-plugin-fn-elasticsearch-1.0.8.tgz: package/src/actions/indices.js <==
const { ElasticsearchClient } = require('./ElasticsearchClient');

/**
 * Action method.
 * @param {object} req - The flow request context passed in at runtime.  The
 *	 parameters are resolved as `req.params` and the available authorization
 * credentials are passed in as `req.authorizations`.
 * @param {object} outputs - A set of output callbacks.  Use it to signal an
 *	 event and pass the output result back to the runtime.  Only use an
 *	 output callback once and only after all asyncronous tasks complete.
 * @param {object} options - The additional options provided from the flow
 * 	 engine.
 * @param {object} The logger from API Builder that can be used to log messages
 * 	 to the console. See https://docs.axway.com/bundle/API_Builder_4x_allOS_en/page/logging.html
 *
 * @return {undefined}
 */

async function indicesRollover(params, options) {
	const elasticSearchConfig = options.pluginConfig.elastic;

	if (typeof elasticSearchConfig.node === 'undefined' && typeof elasticSearchConfig.nodes === 'undefined') {
		options.logger.error('Elasticsearch configuration is invalid: nodes or node is missing.');
		throw new Error('Elasticsearch configuration is invalid: nodes or node is missing.');
	}
	if (!params.alias) {
		throw new Error('Missing required parameter: alias');
	}
	// The alias might be a string or an object 
	if(typeof params.alias === 'object') {
		if(Object.keys(params.alias).length === 0 && params.alias.constructor === Object) {
			throw new Error(`Given rollover alias object is empty.`);
		}
		for(var alias in params.alias) {
			params.alias = alias;
			break; // Only one alias is supported.
		}
	}
	try {
		var client = new ElasticsearchClient(elasticSearchConfig).client;
		var result = await client.indices.rollover( params, { ignore: [404], maxRetries: 3 });

		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}

async function indicesCreate(params, options) {
	const elasticSearchConfig = options.pluginConfig.elastic;

	if (typeof elasticSearchConfig.node === 'undefined' && typeof elasticSearchConfig.nodes === 'undefined') {
		options.logger.error('Elasticsearch configuration is invalid: nodes or node is missing.');
		throw new Error('Elasticsearch configuration is invalid: nodes or node is missing.');
	}
	if (!params.index) {
		throw new Error('Missing required parameter: index');
	}
	try {
		var aliasName;
		if(params.alias) {
			aliasName = params.alias;
			delete params.alias;
			if(params.body) { // a body might be given
				if(params.body.aliases == undefined) {
					params.body.aliases = {};
				}
			} else {
				params.body = { aliases: { }};
			}
			params.body.aliases[aliasName] = {};
		}
		var client = new ElasticsearchClient(elasticSearchConfig).client;
		var result = await client.indices.create( params, { ignore: [404], maxRetries: 3 });

		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}

async function indicesExists(params, options) {
	const elasticSearchConfig = options.pluginConfig.elastic;

	if (typeof elasticSearchConfig.node === 'undefined' && typeof elasticSearchConfig.nodes === 'undefined') {
		options.logger.error('Elasticsearch configuration is invalid: nodes or node is missing.');
		throw new Error('Elasticsearch configuration is invalid: nodes or node is missing.');
	}
	if (!params.index && !params.name) {
		throw new Error('Either the parameter index, name (name of the alias) or both must be given');
	}

	try {
		var client = new ElasticsearchClient(elasticSearchConfig).client;
		var result;
		// If the alias is given, we search for the alias in combination with the index
		if(params.name != undefined) {
			result = await client.indices.existsAlias( params, { ignore: [404], maxRetries: 3 });
		} else {
			// This searches for indices only
			result = await client.indices.exists( params, { ignore: [404], maxRetries: 3 });
		}
		if(result.statusCode == 404) {
			return options.setOutput('notFound', result);
		}

		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}



module.exports = {
	indicesRollover, 
	indicesCreate, 
	indicesExists
};

==> api-builder-plugin-fn-elasticsearch-1.0.16.tgz: package/src/actions/indices.js <==
const { ElasticsearchClient } = require('./ElasticsearchClient');

/**
 * Action method.
 * @param {object} req - The flow request context passed in at runtime.  The
 *	 parameters are resolved as `req.params` and the available authorization
 * credentials are passed in as `req.authorizations`.
 * @param {object} outputs - A set of output callbacks.  Use it to signal an
 *	 event and pass the output result back to the runtime.  Only use an
 *	 output callback once and only after all asyncronous tasks complete.
 * @param {object} options - The additional options provided from the flow
 * 	 engine.
 * @param {object} The logger from API Builder that can be used to log messages
 * 	 to the console. See https://docs.axway.com/bundle/API_Builder_4x_allOS_en/page/logging.html
 *
 * @return {undefined}
 */

async function indicesRollover(params, options) {
	var { alias, wildcardAlias } = params;
	var { logger } = options;
	var client = new ElasticsearchClient().client;
	debugger;
	if (!alias) {
		throw new Error('Missing required parameter: alias');
	}
	var aliasesToRollover = [];
	// The alias might be a string or an object 
	if(typeof alias === 'object') {
		for(var alias in alias) {
			aliasesToRollover.push(alias);
			break; // Only one alias is supported.
		}
	} else {
		aliasesToRollover.push(alias);
	}
	// Is the given alias is a wildcard, search for other indicies starting with this alias
	if(wildcardAlias) {
		aliasesToRollover = [];
		logger.debug(`Rolling over all indicies starting with alias: ${alias}`);
		var indicesFound = await client.indices.getAlias({name: `${alias}*`}, { ignore: [404], maxRetries: 3 });
		for (const index of Object.values(indicesFound.body)) {
			var indexAlias = Object.keys(index.aliases)[0];
			aliasesToRollover.push(indexAlias);
		}	
	}
	if(aliasesToRollover.length == 0) {
		throw new Error(`No index found to rollover for alias: ${JSON.stringify(alias)}`);
	}
	try {
		var result = [];
		for(alias of aliasesToRollover) {
			var rolloverResult = await client.indices.rollover( { alias: alias }, { ignore: [404], maxRetries: 3 });
			result.push(rolloverResult);
		}
		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}

async function indicesCreate(params, options) {
	const elasticSearchConfig = options.pluginConfig.elastic;

	if (typeof elasticSearchConfig.node === 'undefined' && typeof elasticSearchConfig.nodes === 'undefined') {
		options.logger.error('Elasticsearch configuration is invalid: nodes or node is missing.');
		throw new Error('Elasticsearch configuration is invalid: nodes or node is missing.');
	}
	if (!params.index) {
		throw new Error('Missing required parameter: index');
	}
	try {
		var aliasName;
		if(params.alias) {
			aliasName = params.alias;
			delete params.alias;
			if(params.body) { // a body might be given
				if(params.body.aliases == undefined) {
					params.body.aliases = {};
				}
			} else {
				params.body = { aliases: { }};
			}
			params.body.aliases[aliasName] = {};
		}
		var client = new ElasticsearchClient(elasticSearchConfig).client;
		var result = await client.indices.create( params, { ignore: [404], maxRetries: 3 });

		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}

async function indicesExists(params, options) {
	const elasticSearchConfig = options.pluginConfig.elastic;

	if (typeof elasticSearchConfig.node === 'undefined' && typeof elasticSearchConfig.nodes === 'undefined') {
		options.logger.error('Elasticsearch configuration is invalid: nodes or node is missing.');
		throw new Error('Elasticsearch configuration is invalid: nodes or node is missing.');
	}
	if (!params.index && !params.name) {
		throw new Error('Either the parameter index, name (name of the alias) or both must be given');
	}

	try {
		var client = new ElasticsearchClient(elasticSearchConfig).client;
		var result;
		// If the alias is given, we search for the alias in combination with the index
		if(params.name != undefined) {
			result = await client.indices.existsAlias( params, { ignore: [404], maxRetries: 3 });
		} else {
			// This searches for indices only
			result = await client.indices.exists( params, { ignore: [404], maxRetries: 3 });
		}
		if(result.statusCode == 404) {
			return options.setOutput('notFound', result);
		}

		return result;
	} catch (e) {
		if(e instanceof Error) throw e;
		throw new Error(JSON.stringify(e));
	}
}



module.exports = {
	indicesRollover, 
	indicesCreate, 
	indicesExists
};
